# Einleitung

Smartphones enthalten immer mehr Sensoren, mit denen sie Daten aus ihrer Umwelt erfassen. Erst durch den Zugriff über Software werden diese Sensordaten zu nützlichen Features. So wird Beispielsweise das Display eingeschaltet sobald man das Smartphone aus der Hosentasche holt oder ausgeschaltet wenn man es sich ans Ohr hält. Ein großes Augenmerk erhält die Lokalisierung der Geräte. Hierdurch werden Anwendungen wie die Navigation ermöglicht. Bei der Distanzmessung geht es darum, die Strecke, die ein Gerät in Bewegung zurücklegt, zu erfassen. In dieser Arbeit soll untersucht werden, wie die Messung auf kleinen Skalen, im Zentimeterbereich umgesetzt werden kann.

## Motivation und Ausgangslage

Der Fokus dieser Arbeit liegt auf der Umsetzung der Distanzmessung mittels Bluetooth unter Verwendung des \ac{rssi}. Diese Lösung wird häufig in der Indoor-Navigation angewandt, da sie sowohl kostengünstig als auch weit verbreitet ist. Hierbei findet die Lokalisierung der Geräte zum Beispiel durch Triangulation mittels Referenzpunkten statt. Diese Reverenz punkte sind als Bluetoothbeacon bezeichnet. Sie können sowohl weitere Smartphones als auch dedizierte Hardware sein. Bei der Indoor-Navigation sind diese Referenzpunkte mehrere Meter auseinander, was zu einer geringen Signalstärke am Empfänger und somit zu größeren Auswirkungen von Störeinflüssen führt. Bei der Messung von kleinen Skalen können die Bluetooth Beacons in einem engeren Raster angeordnet werden. 

## Zielsetzung

Das Ziel der Arbeit ist es, die Genauigkeit einer Distanzmessung auf einem eingeschränkten Bereich von rund \SI{2}{\meter} zu erhöhen. Das gewählte Setup soll dabei möglichst einfach umsetzbar sein.
Mithilfe einer Beispielimplementierung soll die Genauigkeit dieses Setups untersucht werden. Zur weiteren Verbesserung der Genauigkeit sollen verschiedene Filtermöglichkeiten implementiert werden. Mit einer genauen Distanzmessung lassen sich Beispielsweise neue Experimente mit dem Smartphone umsetzen.

---

Im Smartphone befinden sich mehrere Sensoren, die zur Lokalisierung des Geräts eingesetzt werden können. Da sich die Experimente mit phyphox&reg; meist im Innenraum abspielen, wird GPS für diesen Einsatzzweck nicht betrachtet. Mithilfe von WLAN, Bluetooth, NFC, Magnetometer, Gyroskop, Accelerometer, Kamera und Ultraschall bleiben jedoch viele weitere Möglichkeiten zur Lokalisierung bestehen [@maghdid_comprehensive_2021].

Bei der Smartphone-Anwendung phyphox&reg; handelt es sich um eine Open-Source-Anwendung, mit deren Hilfe Experimente mit dem Smartphone durchgeführt werden können. Hierzu greift sie auf die im Gerät verbauten Sensoren zurück. So lassen sich zum Beispiel mit dem Luftdrucksensor die im Fahrstuhl zurückgelegten Stockwerke ermitteln und anzeigen, oder die Länge eines Pendels, an dem das Smartphone hängt, durch die Pendelfrequenz berechnen. Anwender können mithilfe von XML-Dateien die Anwendung um eigene Experimente erweitern. Hierdurch wird phyphox&reg; gerade für Schulen interessant, da es Schülern die Möglichkeit bietet, die Theorie in der Praxis zu erleben. Aktuell fehlt jedoch eine Möglichkeit zur Distanzmessung. Durch diese könnten Experimente wie die Errechnung der Beschleunigung aus der zurückgelegten Wegstrecke und der Zeit durchgeführt werden.

Um eine genaue Distanzmessung durchführen zu können muss die Punktuelle Lokalisation eines Gerätes möglich genau sein. 

Die Distanz beschreibt die Länge einer, durch eine dynamische Bewegung zurückgelegten Strecke. Die Entfernung hingegen beschreibt den Abstand zwischen zwei Punkten im Raum. Die Lokalisierung bezeichnet die Position in einem 2D oder 3D Raum.

---

## Aufbau der Arbeit

# Technische Grundlagen

In diesem Artikel werden die Technischen Grundlagen erörtert und eine Abschließende Bewertung durchgeführt. Dabei werden die Grundlagen zunächst allgemein Betrachtet und in weiteren Kapiteln vertieft.

## Distanzmessung

Die Distanzmessung beschreibt im Rahmen dieser Arbeit die Messung der Länge einer zurückgelegten Strecke. Dabei bezeichnet die Strecke den Weg zwischen Start- und Zielpunkt. Die digitale Erfassung einer Strecke basiert auf der Erfassung einzelner Wegpunkte [@Lerch_2006_BOOK S. 7 ff.]. Da zwischen den Wegpunkten keine Informationen vorliegen, wird dieser Zwischenraum als Gerade angenommen. Wie Abbildung \ref{fig:wegpunkte} verdeutlicht, wird die Streckenabbildung durch die Anzahl an aufgezeichneten Wegpunkten verbessert. 

![Auswirkung der Genauigkeit und Häufigkeit der Wegpunkterfassung \label{fig:wegpunkte}](../static/wegpunkte.png)

## Lokalisierung

Die Lokalisierung bezeichnet die genaue Position in einem 2D oder 3D Raum. Die verschiedene Methoden zur Lokalisierung werden in den Folgenden Kapiteln näher erläutert. 

### Anwesenheit und Räumliche Nähe

Die einfachste Form der Positionsbestimmung ist, zu Prüfen ob sich das Objekt in einem bestimmten Areal befindet. Hierbei ist die Auflösung vom Raster des Areals abhängig. Beim Einsatz von funkbasierten Systemen kann dieses Areal mehrere Zentimeter bis hin zu Kilometer groß sein. Die Genauigkeit lässt sich erhöhen, indem mehr Funksender kombiniert werden, deren Senderadius sich überlappt. 

### Entfernungsmessung

Bei der Entfernungsmessung geht es darum den Abstand zwischen zwei Punkten zu ermitteln. Dies ist für viele Methoden die Grundlage zur Lokalisierung. 

### Trilateration


## Smartphonesensoren

Aktuelle Smartphones besitzen eine viel zahl von Sensoren um mit ihrer Umwelt zu Interagieren. Viele der Sensoren lassen sich alleine oder in Kombination zur Entfernungsmessung oder auch Distanzmessung einsetzen [@Subbu_2013] [@Chen_2019] [@Li_2012] [@SosaSesma_2016]. 

Die Entfernung zu einem Referenzpunkt wie einer Wand, lässt sich zum Beispiel durch den Einsatz eines Sonars messen. Für die Umsetzung kommen das Mikrofons und der Lautsprecher des Smartphones in Frage [@Graham_2015]. In dieser Arbeit geht es jedoch um einen flexibleren Einsatzbereich, bei dem eine Lokalisierung zwingend erforderlich ist.

Der bekanntesten Sensoren zur Lokalisierung ist das \ac{gps}. Hierbei wird, mit Hilfe von Satelliten die Position des Smartphones ermittelt. Dies ermöglicht die Ortung außerhalb von Gebäuden mit einer Genauigkeit von wenigen Metern [@Bajaj_2002a]. Da die Messungen jedoch nicht auf den Außenbereich beschränkt sein sollen, wird \ac{gps} nicht näher betrachtet.

Die Innenraum- Lokalisierung und Navigation ist ein Forschungsfeld mit großem Interesse. Viele Arbeiten basieren auf dem vom \ac{ieee} festgelegten Standard IEEE 802.11, besser bekannt als \ac{wifi} [@Chen_2019]. Für den Einsatz von \ac{wifi} zur Lokalisierung muss zunächst eine Karte mit der Funkstärkenverteilung erstellt werden [@Davidson_2017a]. Dies bedeutet einen hohen zeitlichen Aufwand bei der Einrichtung und eine geringe Flexibilität im Einsatz.

Ein weiterer Sensor der zur Lokalisierung in Innenräumen häufig betrachtet wird ist Bluetooth. Er ist weit verbreitet und kostengünstiger als \ac{wifi} [@Ye_2019]. Des weiteren wurde mit \ac{ble} ein Standard entwickelt der sehr stromsparend ist. Im weiteren Verlauf der Arbeit soll Bluetooth näher betrachtet.

## Bluetooth

Bei Bluetooth handelt es sich um einen durch die \ac{sig} entwickelten Industriestandard zur Datenübertragung über kurze Distanzen per Funktechnik. Bluetooth arbeitet im lizenzfreiem \ac{ism} von \SIrange{2,402}{2,480}{\giga\Hz}, dadurch darf es Weltweit zulassungsfrei betrieben werden. Mit Bluetooth 4.0 wurde \acl{ble} eingeführt. Dieses ist nicht abwärtskompatibel, bietet jedoch einige nützliche Besonderheiten. Ein Reduzierter Stromverbrauch und die kurze Aufbauzeit einer Übertragung sind die wesentlichen Vorteile. 

\acl{ble} befindet sich im gleichen \ac{ism} wie das klassische Bluetooth. Es teilt den Frequenzbereich jedoch nicht in 79 Kanälen von \SI{1}{\mega\Hz} sondern in 40 Kanälen von je \SI{2}{\mega\Hz} auf.

### BLE und Entfernungsmessung

## Messkette

## Fehlerkorrekturen

### Fingerprinting

### Filter

## Bewertung

## Beschreibung der eigenen Idee/ Innovation

# Implementierung

## Hardware

## Software

### Android App

### Bluetooth Beacon

# Testaufbau

In diesem Kapitel wird der Versuchsaufbau beschrieben. Dieser Orientiert sich an den Anforderungen aus dem Vorherigen Kapitel. Im Fokus steht hierbei die Umsetzung eines einfach um zu setzenden Versuchsaufbau der eine möglichst genaue Messung ermöglicht.

## Anordnung der Beacon

Die Bluetooth Beacon werden in einem gleichseitigen Dreieck mit einer Seitenlänge von \SI{1}{\meter} auf einer Ebenen fläche angeordnet (Abbildung \ref{fig:versuchsaufbau}). Hierdurch empfängt jeder Beacon von seinen Nachbarn den RSSI Wert auf \SI{1}{\meter} Entfernung und kann diesen zur Kalibrierung an das Smartphone übermitteln. Dieser Versuchsaufbau ermöglicht es, das System um weitere Beacon zu erweitern. Auch ließe sich hierdurch eine 6 Seitige Pyramidenform umsetzen um die Messung auf die 3. Dimension zu erweitern.

## Messpunkte

Der Versuchsaufbau wird, wie in Abbildung \ref{fig:zones} dargestellt, in drei Zonen eingeteilt. Die ersten beiden Zonen ergeben sich aus der Geometrie des Versuchsaufbaus. Zone 1 hat einen Radius von \SI{0.289}{\meter} und wird durch das gleichseitige Dreieck begrenzt. In dieser Zone ist kein Beacon weiter als \SI{0.866}{\meter} vom Smartphone entfernt. Zone 2 misst einen Radius von \SI{0.577}{\meter} und schließt das Dreieck ein. Die maximale Distanz zu einem Beacon beträgt \SI{1.154}{\meter}. 

Zone 3 ergibt sich aus dem, im Artikel [@Cho_2015a] beschriebenen maximal sinnvollen Messabstand von \SI{1.5}{\meter}. Der weitest entfernte Punkt von einem Beacon ist somit \SI{1.5}{\meter}. Daraus ergibt sich ein Radius von \SI{1.067}{\meter} um das Zentrum.

Zu den Messpunkten in und am Rand der Zonen kommt ein spezieller Messpunkt. Dieser befindet sich auf einer Seite des Dreiecks und liegt somit genau zwischen zwei Beacon. Er wurde gewählt um den Einfluss des Smartphones auf die Funkstrecke der Beacon zu untersuchen.

![Aufteilung des Versuchsaufbaus in Zonen und Messpunkte \label{fig:zones}](../static/zonen_und_messpunkte.png)

# Messauswertung

# Ergebnisse

# Zusammenfassung und Ausblick

## Zusammenfassung und Fazit

## Ausblick

# Abkürzungsverzeichnis

\begin{acronym}[ISM-Band]

\acro{ble}[BLE]{Bluetooth Low Energy}
\acro{gps}[GPS]{Global Positioning System}
\acro{ieee}[IEEE]{Institute of Electrical and Electronics Engineers}
\acro{ism}[ISM-Band]{Industrial, Scientific and Medical Band}
\acro{rssi}[RSSI]{eceived Signal Strength Indicator}
\acro{sig}[SIG]{Bluetooth Special Interest Group}
\acro{wifi}[WiFi]{Wireless Fidelity}

\end{acronym}

# Quellenverzeichnis